from setuptools import setup
 
setup(name='ltrhieu1994',
      version='0.2',
      description='Hello World',
      url='',
      author='Hieu Le',
      author_email='ltrhieu1994@gmail.com',
      license='BKU',
      packages=['leedsx'],
      zip_safe=False)